(ANY path args & body)(context path args & body)(DELETE path args & body)(fix-params-in-path path)Replace a path param such as /:id with corresponding /{id}
Replace a path param such as /:id with corresponding /{id}
(fix-paths swagger-spec)Replace all path params under :paths such as /:id/:name with corresponding /{id}/{name}
Replace all path params under :paths such as /:id/:name with corresponding /{id}/{name}
(GET path args & body)(POST path args & body)(PUT path args & body)(routes & handlers)(swagger-api options swag-routes)Create an endpoint which contains swagger docs for swag-routes
Create an endpoint which contains swagger docs for swag-routes
(swagger-spec options swag-routes)(swagify-route route)(swagify-verb verb)(with-swagger route swagger)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |